import React from "react";
import PropTypes from "prop-types";
import { useSelector } from "react-redux";
import { Link } from "react-router-dom";

import { Torrent } from "./torrent";
import { Poster } from "./poster";

export const TorrentGroup = ({ torrentKey }) => {
  const torrents = useSelector((state) =>
    state.torrents.torrents.get(torrentKey)
  );

  if (torrents.length === 0) {
    return null;
  }

  const title = (torrent) => {
    switch (torrent.type) {
      case "movie":
        return (
          <Link
            className="link-unstyled"
            to={`/movies/details/${torrent.video.imdb_id}`}
          >
            {torrent.video.title}
          </Link>
        );
      case "episode":
        return (
          <Link
            className="link-unstyled"
            to={`/shows/details/${torrent.video.show_imdb_id}`}
          >
            {torrent.video.show_title}
          </Link>
        );
      default:
        return <span>Files</span>;
    }
  };

  return (
    <div className="w-100 mb-3 card">
      <div className="row no-gutters">
        <Poster thumb={torrents[0].thumb} fanart={torrents[0].fanart} />
        <div className="col-sm">
          <div className="card-body">
            <h4 className="card-title">{title(torrents[0])}</h4>
            {torrents.map((torrent, i) => (
              <Torrent
                key={torrent.video ? torrent.video.imdb_id : i}
                torrent={torrent}
              />
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};
TorrentGroup.propTypes = {
  torrentKey: PropTypes.string.isRequired,
};
